# Changelog

## [7.0.0a1](https://github.com/OpenVoiceOS/ovos-workshop/tree/7.0.0a1) (2025-06-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-workshop/compare/6.0.1...7.0.0a1)

**Breaking changes:**

- fix!: rename can\_answer -\> can\_converse [\#348](https://github.com/OpenVoiceOS/ovos-workshop/pull/348) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
